@@ -234,7 +234,7 @@ KTextEdit::KTextEdit(const QString &text, QWidget *parent)
 
 KTextEdit::KTextEdit(KTextEditPrivate &dd, const QString &text, QWidget *parent)
     : QTextEdit(text, parent)
-    , d(&dd)
+    , d_ptr(&dd)
 {
     Q_D(KTextEdit);
 
@@ -248,7 +248,7 @@ KTextEdit::KTextEdit(QWidget *parent)
 
 KTextEdit::KTextEdit(KTextEditPrivate &dd, QWidget *parent)
     : QTextEdit(parent)
-    , d(&dd)
+    , d_ptr(&dd)
 {
     Q_D(KTextEdit);
 
@@ -619,8 +619,11 @@ void KTextEdit::clearDecorator()
 {
     Q_D(KTextEdit);
 
-    delete d->decorator;
+    // Set pointer to null before deleting KTextDecorator as dtor will emit signal,
+    // which could call this code again and cause double delete/crash
+    auto decorator = d->decorator;
     d->decorator = nullptr;
+    delete decorator;
 }
 
 void KTextEdit::addTextDecorator(Sonnet::SpellCheckDecorator *decorator)
@@ -705,8 +708,11 @@ void KTextEdit::setReadOnly(bool readOnly)
     }
 
     if (readOnly) {
-        delete d->decorator;
+        // Set pointer to null before deleting KTextDecorator as dtor will emit signal,
+        // which could call this code again and cause double delete/crash
+        auto decorator = d->decorator;
         d->decorator = nullptr;
+        delete decorator;
 
         d->customPalette = testAttribute(Qt::WA_SetPalette);
         QPalette p = palette();
@@ -798,18 +804,9 @@ void KTextEdit::slotDoReplace()
     });
     connect(d->replace, &KFind::findNext, this, &KTextEdit::slotReplaceNext);
 
-#if KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(5, 81)
-    connect(d->replace,
-            qOverload<const QString &, int, int, int>(&KReplace::replace),
-            this,
-            [d](const QString &text, int replacementIndex, int replacedLength, int matchedLength) {
-                d->slotReplaceText(text, replacementIndex, replacedLength, matchedLength);
-            });
-#else
     connect(d->replace, &KReplace::textReplaced, this, [d](const QString &text, int replacementIndex, int replacedLength, int matchedLength) {
         d->slotReplaceText(text, replacementIndex, replacedLength, matchedLength);
     });
-#endif
 
     d->repDlg->close();
     slotReplaceNext();
